@@ -13,12 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
+from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
-from google.cloud.datalabeling_v1beta1.types import annotation
-from google.cloud.datalabeling_v1beta1.types import annotation_spec_set
-from google.protobuf import timestamp_pb2  # type: ignore
-
+from google.cloud.datalabeling_v1beta1.types import annotation, annotation_spec_set
 
 __protobuf__ = proto.module(
     package="google.cloud.datalabeling.v1beta1",
@@ -72,17 +72,39 @@ class Evaluation(proto.Message):
             is for certain AnnotationTypes.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    config = proto.Field(proto.MESSAGE, number=2, message="EvaluationConfig",)
-    evaluation_job_run_time = proto.Field(
-        proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    create_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    evaluation_metrics = proto.Field(
-        proto.MESSAGE, number=5, message="EvaluationMetrics",
+    config: "EvaluationConfig" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="EvaluationConfig",
+    )
+    evaluation_job_run_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    create_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    evaluation_metrics: "EvaluationMetrics" = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="EvaluationMetrics",
+    )
+    annotation_type: annotation.AnnotationType = proto.Field(
+        proto.ENUM,
+        number=6,
+        enum=annotation.AnnotationType,
+    )
+    evaluated_item_count: int = proto.Field(
+        proto.INT64,
+        number=7,
     )
-    annotation_type = proto.Field(proto.ENUM, number=6, enum=annotation.AnnotationType,)
-    evaluated_item_count = proto.Field(proto.INT64, number=7,)
 
 
 class EvaluationConfig(proto.Message):
@@ -102,7 +124,7 @@ class EvaluationConfig(proto.Message):
             This field is a member of `oneof`_ ``vertical_option``.
     """
 
-    bounding_box_evaluation_options = proto.Field(
+    bounding_box_evaluation_options: "BoundingBoxEvaluationOptions" = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="vertical_option",
@@ -122,7 +144,10 @@ class BoundingBoxEvaluationOptions(proto.Message):
             must be a number between 0 and 1.
     """
 
-    iou_threshold = proto.Field(proto.FLOAT, number=1,)
+    iou_threshold: float = proto.Field(
+        proto.FLOAT,
+        number=1,
+    )
 
 
 class EvaluationMetrics(proto.Message):
@@ -144,11 +169,17 @@ class EvaluationMetrics(proto.Message):
             This field is a member of `oneof`_ ``metrics``.
     """
 
-    classification_metrics = proto.Field(
-        proto.MESSAGE, number=1, oneof="metrics", message="ClassificationMetrics",
+    classification_metrics: "ClassificationMetrics" = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        oneof="metrics",
+        message="ClassificationMetrics",
     )
-    object_detection_metrics = proto.Field(
-        proto.MESSAGE, number=2, oneof="metrics", message="ObjectDetectionMetrics",
+    object_detection_metrics: "ObjectDetectionMetrics" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        oneof="metrics",
+        message="ObjectDetectionMetrics",
     )
 
 
@@ -165,8 +196,16 @@ class ClassificationMetrics(proto.Message):
             ground truth labels.
     """
 
-    pr_curve = proto.Field(proto.MESSAGE, number=1, message="PrCurve",)
-    confusion_matrix = proto.Field(proto.MESSAGE, number=2, message="ConfusionMatrix",)
+    pr_curve: "PrCurve" = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="PrCurve",
+    )
+    confusion_matrix: "ConfusionMatrix" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="ConfusionMatrix",
+    )
 
 
 class ObjectDetectionMetrics(proto.Message):
@@ -178,7 +217,11 @@ class ObjectDetectionMetrics(proto.Message):
             Precision-recall curve.
     """
 
-    pr_curve = proto.Field(proto.MESSAGE, number=1, message="PrCurve",)
+    pr_curve: "PrCurve" = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="PrCurve",
+    )
 
 
 class PrCurve(proto.Message):
@@ -194,7 +237,7 @@ class PrCurve(proto.Message):
             Area under the precision-recall curve. Not to
             be confused with area under a receiver operating
             characteristic (ROC) curve.
-        confidence_metrics_entries (Sequence[google.cloud.datalabeling_v1beta1.types.PrCurve.ConfidenceMetricsEntry]):
+        confidence_metrics_entries (MutableSequence[google.cloud.datalabeling_v1beta1.types.PrCurve.ConfidenceMetricsEntry]):
             Entries that make up the precision-recall graph. Each entry
             is a "point" on the graph drawn for a different
             ``confidence_threshold``.
@@ -249,25 +292,67 @@ class PrCurve(proto.Message):
                 [precision_at5][google.cloud.datalabeling.v1beta1.PrCurve.ConfidenceMetricsEntry.precision_at5].
         """
 
-        confidence_threshold = proto.Field(proto.FLOAT, number=1,)
-        recall = proto.Field(proto.FLOAT, number=2,)
-        precision = proto.Field(proto.FLOAT, number=3,)
-        f1_score = proto.Field(proto.FLOAT, number=4,)
-        recall_at1 = proto.Field(proto.FLOAT, number=5,)
-        precision_at1 = proto.Field(proto.FLOAT, number=6,)
-        f1_score_at1 = proto.Field(proto.FLOAT, number=7,)
-        recall_at5 = proto.Field(proto.FLOAT, number=8,)
-        precision_at5 = proto.Field(proto.FLOAT, number=9,)
-        f1_score_at5 = proto.Field(proto.FLOAT, number=10,)
+        confidence_threshold: float = proto.Field(
+            proto.FLOAT,
+            number=1,
+        )
+        recall: float = proto.Field(
+            proto.FLOAT,
+            number=2,
+        )
+        precision: float = proto.Field(
+            proto.FLOAT,
+            number=3,
+        )
+        f1_score: float = proto.Field(
+            proto.FLOAT,
+            number=4,
+        )
+        recall_at1: float = proto.Field(
+            proto.FLOAT,
+            number=5,
+        )
+        precision_at1: float = proto.Field(
+            proto.FLOAT,
+            number=6,
+        )
+        f1_score_at1: float = proto.Field(
+            proto.FLOAT,
+            number=7,
+        )
+        recall_at5: float = proto.Field(
+            proto.FLOAT,
+            number=8,
+        )
+        precision_at5: float = proto.Field(
+            proto.FLOAT,
+            number=9,
+        )
+        f1_score_at5: float = proto.Field(
+            proto.FLOAT,
+            number=10,
+        )
 
-    annotation_spec = proto.Field(
-        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
+    annotation_spec: annotation_spec_set.AnnotationSpec = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=annotation_spec_set.AnnotationSpec,
     )
-    area_under_curve = proto.Field(proto.FLOAT, number=2,)
-    confidence_metrics_entries = proto.RepeatedField(
-        proto.MESSAGE, number=3, message=ConfidenceMetricsEntry,
+    area_under_curve: float = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
+    confidence_metrics_entries: MutableSequence[
+        ConfidenceMetricsEntry
+    ] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message=ConfidenceMetricsEntry,
+    )
+    mean_average_precision: float = proto.Field(
+        proto.FLOAT,
+        number=4,
     )
-    mean_average_precision = proto.Field(proto.FLOAT, number=4,)
 
 
 class ConfusionMatrix(proto.Message):
@@ -276,7 +361,7 @@ class ConfusionMatrix(proto.Message):
     labels. Not applicable when the entry is for a single label.
 
     Attributes:
-        row (Sequence[google.cloud.datalabeling_v1beta1.types.ConfusionMatrix.Row]):
+        row (MutableSequence[google.cloud.datalabeling_v1beta1.types.ConfusionMatrix.Row]):
 
     """
 
@@ -292,10 +377,15 @@ class ConfusionMatrix(proto.Message):
                 this entry's parent.)
         """
 
-        annotation_spec = proto.Field(
-            proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
+        annotation_spec: annotation_spec_set.AnnotationSpec = proto.Field(
+            proto.MESSAGE,
+            number=1,
+            message=annotation_spec_set.AnnotationSpec,
+        )
+        item_count: int = proto.Field(
+            proto.INT32,
+            number=2,
         )
-        item_count = proto.Field(proto.INT32, number=2,)
 
     class Row(proto.Message):
         r"""A row in the confusion matrix. Each entry in this row has the
@@ -305,19 +395,29 @@ class ConfusionMatrix(proto.Message):
             annotation_spec (google.cloud.datalabeling_v1beta1.types.AnnotationSpec):
                 The annotation spec of the ground truth label
                 for this row.
-            entries (Sequence[google.cloud.datalabeling_v1beta1.types.ConfusionMatrix.ConfusionMatrixEntry]):
+            entries (MutableSequence[google.cloud.datalabeling_v1beta1.types.ConfusionMatrix.ConfusionMatrixEntry]):
                 A list of the confusion matrix entries. One
                 entry for each possible predicted label.
         """
 
-        annotation_spec = proto.Field(
-            proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
+        annotation_spec: annotation_spec_set.AnnotationSpec = proto.Field(
+            proto.MESSAGE,
+            number=1,
+            message=annotation_spec_set.AnnotationSpec,
         )
-        entries = proto.RepeatedField(
-            proto.MESSAGE, number=2, message="ConfusionMatrix.ConfusionMatrixEntry",
+        entries: MutableSequence[
+            "ConfusionMatrix.ConfusionMatrixEntry"
+        ] = proto.RepeatedField(
+            proto.MESSAGE,
+            number=2,
+            message="ConfusionMatrix.ConfusionMatrixEntry",
         )
 
-    row = proto.RepeatedField(proto.MESSAGE, number=1, message=Row,)
+    row: MutableSequence[Row] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=Row,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
